@@ -9,14 +9,13 @@
 #include "ShortcutActions.h"
 
 #include <KShortcutsEditor>
-#include <kxmlgui_version.h>
 
 #include <QVBoxLayout>
 
-ShortcutsOptionsPage::ShortcutsOptionsPage(QWidget* parent) : QWidget(parent)
+ShortcutsOptionsPage::ShortcutsOptionsPage(QWidget *parent)
+    : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    setLayout(mainLayout);
+    auto mainLayout = new QVBoxLayout(this);
     mEditor = new KShortcutsEditor(ShortcutActions::self()->shortcutActions(), this, KShortcutsEditor::ActionType::GlobalAction);
     mainLayout->addWidget(mEditor);
     connect(mEditor, &KShortcutsEditor::keyChange, this, &ShortcutsOptionsPage::shortCutsChanged);
@@ -24,21 +23,12 @@ ShortcutsOptionsPage::ShortcutsOptionsPage(QWidget* parent) : QWidget(parent)
 
 ShortcutsOptionsPage::~ShortcutsOptionsPage()
 {
-#if KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 75, 0)
     mEditor->undo();
-#else
-    mEditor->undoChanges();
-#endif
 }
 
-
 void ShortcutsOptionsPage::resetChanges()
 {
-#if KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 75, 0)
     mEditor->undo();
-#else
-    mEditor->undoChanges();
-#endif
 }
 
 void ShortcutsOptionsPage::saveChanges()
@@ -46,14 +36,12 @@ void ShortcutsOptionsPage::saveChanges()
     mEditor->commit();
 }
 
-bool ShortcutsOptionsPage::isModified()
+bool ShortcutsOptionsPage::isModified() const
 {
     return mEditor->isModified();
 }
 
-void ShortcutsOptionsPage::defaults()
+void ShortcutsOptionsPage::defaults() const
 {
     mEditor->allDefault();
 }
-
-
